# Changelog

## 0.2.0 (2025-07-03)

Full Changelog: [v0.1.8...v0.2.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.1.8...v0.2.0)

### Features

* **api:** api key fix ([7515bca](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/7515bcad6ea549008901dbb187d736b3a996b812))
* **api:** fix stainless.yml ([6a102e3](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/6a102e3dedae261e65ce7a383cec76cb0737ab46))

## 0.1.8 (2025-07-03)

Full Changelog: [v0.1.7...v0.1.8](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.1.7...v0.1.8)

### Chores

* sync repo ([f789c08](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/f789c08eeb01cbbd6a2be8f70f341c99d362fb22))
* update SDK settings ([07b018a](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/07b018af809179258493151a1d0175d4651f65e6))
* update SDK settings ([07a3fff](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/07a3fff84c29b9f2d2f40a3205ff4e92b45dbbdf))
